@@ -13,8 +13,8 @@ class ChargeControllerLite(ChargeControllerBase):
             ret = CHARGERSTATES.Start
         return ret
 
-    def _get_status_connected(self, charger_state) -> CHARGERSTATES:
-        if self._hub.carpowersensor.value < 1 and self._is_done(charger_state):
+    def _get_status_connected(self, charger_state = None) -> CHARGERSTATES:
+        if charger_state is not None and self._hub.sensors.carpowersensor.value < 1 and self._is_done(charger_state):
             ret = CHARGERSTATES.Done
         else:
             if (self._hub.totalhourlyenergy.value < self._hub.current_peak_dynamic) or self._hub.locale.data.free_charge(self._hub.locale.data) is True:
